#version 120
#extension GL_ARB_draw_buffers : require
#extension GL_EXT_gpu_shader4 : require

//
// Fragment shader for evaluating a 1D gaussian blur.
//
// Author: Evan Hart
// Email: sdkfeedback@nvidia.com
//
// Copyright (c) NVIDIA Corporation. All rights reserved.
////////////////////////////////////////////////////////////////////////////////

varying vec2 texCoord;

uniform sampler2D tex;
uniform float sigma = 2.0;

//direction to perfom the gaussian
uniform vec2 direction = vec2( 1.0, 0.0);

//level to take the texture sample from
uniform float level = 0.0;

void main() {
	vec2 size = vec2( textureSize2D( tex, 0));
	vec2 offset = exp2( level) / size; 
	
	//compute the radius across the kernel
	int radius = int( floor(3.0*sigma) - 1.0);
	
	vec4 accum = vec4(0.0);
	
	//precompute factors used every iteration
	float sigmaSqx2 = sigma * sigma * 2.0;
	float sigmaxSqrt2PI = sqrt(2.0 * 3.1415926) * sigma;
	
	// separable Gaussian
    for ( int ii = -radius; ii <= radius; ii++) {
        float r = float(ii);
	    float factor = pow( 2.71828, -(r*r) / sigmaSqx2 ) / sigmaxSqrt2PI;
	    accum += factor * texture2DLod( tex, texCoord + r * direction * offset, level);
	}
		
	gl_FragColor = accum;
}

