#version 120
#extension GL_EXT_gpu_shader4 : require

//
// Vertex shader for the lights themselves, not the lighting they
// produce.
//
// Author: Evan Hart
// Email: sdkfeedback@nvidia.com
//
// Copyright (c) NVIDIA Corporation. All rights reserved.
////////////////////////////////////////////////////////////////////////////////

varying vec3 color;
varying vec4 hPos;
varying float ptSize;

void main() {
	const float scale = 1.0 / 12.0;
	const vec2 vpScale = vec2(400.0, 300.0);
 	
 	hPos = gl_ModelViewProjectionMatrix * gl_Vertex;
	gl_Position = hPos;
	
	vec4 eyePos = gl_ModelViewMatrix * gl_Vertex;
	
	vec4 p0, p1;
	
	p0 = gl_ProjectionMatrix * ( eyePos + vec4( 0.125, 0.125, 0.0, 0.0) * scale);
	p1 = gl_ProjectionMatrix * ( eyePos - vec4( 0.125, 0.125, 0.0, 0.0) * scale); 
	p0 /= p0.w;
	p1 /= p1.w;
	p0.xy *= vpScale;
	p1.xy *= vpScale;
	p0.xy += vpScale;
	p1.xy += vpScale;
	
	float size = distance( p0.xy, p1.xy);
	
	float lightScale = 1.0;
	
	if (size < 1.0) {
	    lightScale = scale;
	    size = 1.0;
	}
	
	ptSize = size;
	
	color = vec3( 128.0 * lightScale * gl_Color.rgb);
}