#version 120
#extension GL_ARB_draw_buffers : require
#extension GL_EXT_gpu_shader4 : require

//
// Fragment shader for the ornaments. This only fills the MRT for
// the deferred shading.
//
// Author: Evan Hart
// Email: sdkfeedback@nvidia.com
//
// Copyright (c) NVIDIA Corporation. All rights reserved.
////////////////////////////////////////////////////////////////////////////////

varying vec2 texCoord;
varying vec3 eyePosition;
varying vec4 material;
 
void main() {
	
	vec3 normal;
	
	normal.xy = texCoord * 2.0 - 1.0;

    // make the ball circular
	float radius = 1.0 - dot( normal.xy, normal.xy);
	
	if (radius < 0.0)
	    discard;
	    
	normal.z = sqrt(radius);
	  
	normal = normalize(normal);  
	
	vec3 finalEyePos = eyePosition;
	finalEyePos.z += 1.5 / 12.0 * normal.z; //normal is also the normalized displacement from the center 1.5/12.0 is the radius of the ball
		
	gl_FragData[0] = vec4( finalEyePos, 0.0);
	gl_FragData[1] = vec4( normal * 0.5 + 0.5, 1.0);
	gl_FragData[2] = material;
}