#version 120
#extension GL_EXT_gpu_shader4 : require
#extension GL_EXT_geometry_shader4 : require

//
// Geometry shader for the ornaments. This only fills the MRT for
// the deferred shading.
//
// Author: Evan Hart
// Email: sdkfeedback@nvidia.com
//
// Copyright (c) NVIDIA Corporation. All rights reserved.
////////////////////////////////////////////////////////////////////////////////

varying in vec3 position[1];
varying in vec4 mat[1];
varying out vec2 texCoord;
varying out vec3 eyePosition;
varying out vec4 material;


void main() {
	float radius = 2.5f / 12.0f;
	
	//lower left
	eyePosition = position[0] + vec3( -radius, -radius, 0.0);
	gl_Position = gl_ProjectionMatrix * vec4( eyePosition, 1.0);
	texCoord = vec2( 0.0, 0.0);
	material = mat[0];
	
	EmitVertex();
	
	//lower right
	eyePosition = position[0] + vec3( radius, -radius, 0.0);
	gl_Position = gl_ProjectionMatrix * vec4( eyePosition, 1.0);
	texCoord = vec2( 1.0, 0.0);
	material = mat[0];
	
	EmitVertex();
	
	//upper left
	eyePosition = position[0] + vec3( -radius, radius, 0.0);
	gl_Position = gl_ProjectionMatrix * vec4( eyePosition, 1.0);
	texCoord = vec2( 0.0, 1.0);
	material = mat[0];
	
	EmitVertex();
	
	//upper right
	eyePosition = position[0] + vec3( radius, radius, 0.0);
	gl_Position = gl_ProjectionMatrix * vec4( eyePosition, 1.0);
	texCoord = vec2( 1.0, 1.0);
	material = mat[0];
	
	EmitVertex();
	
	EndPrimitive();
}